@@ -11,17 +11,15 @@ class SmartWidget:
       # Can be reset in children.
       self._smartWidgetStyle = StaticUtils.mergeJson(*map(lambda styleName: SmartWidget._STYLE_INSTANCE.configure(styleName) or dict(), [self.__class__.STYLE, kw.get("style", "")]), True)
       
-      for key, value in self._smartWidgetStyle.items():
-         k = key.casefold()
-         
-         for axis in "xy":
-            if f"pad{axis}" in k:
-               value = [value] if isinstance(value, Number) else [float(v) for v in value.split()] if isinstance(value, str) else None
+      for d in (self._smartWidgetGrid, self._smartWidgetStyle):
+         for key, value in d.items():
+            if key in ("padx", "pady", "childPadx", "childPady"):
+               value = [value] if isinstance(value, Number) else [float(v) for v in value.split()] if isinstance(value, str) else value if isinstance(value, list) else None
                
                if len(value) == 1:
                   value.append(value[0])
                
-               self._smartWidgetStyle[key] = value
+               d[key] = value
       
       self.__columns = kw.pop("columns", 1)
       self.__rows = kw.pop("rows", 1)
